@@ -6,20 +6,20 @@
 
 #include "../src/incidencechanger.h"
 
-#include <collection.h>
-#include <collectionfetchjob.h>
-#include <collectionfetchscope.h>
-#include <qtest_akonadi.h>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <akonadi/qtest_akonadi.h>
 
-#include <item.h>
-#include <itemcreatejob.h>
-#include <itemdeletejob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <Akonadi/Item>
+#include <Akonadi/ItemCreateJob>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
-#include <kcalendarcore/todo.h>
+#include <KCalendarCore/Todo>
 
 #include <QBitArray>
 
@@ -538,17 +538,17 @@ private Q_SLOTS:
             } else {
                 QCOMPARE(incidence->attendeeByMail(s_ourEmail).status(), Attendee::NeedsAction);
             }
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul")).status(), Attendee::NeedsAction);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul")).RSVP(), true);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul")).status(), Attendee::Delegated);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul")).RSVP(), false);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul")).status(), Attendee::Accepted);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul")).RSVP(), false);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("mia@dev.nul")).status(), Attendee::NeedsAction);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("mia@dev.nul")).RSVP(), true);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("vincent@dev.nul")).status(), Attendee::Delegated);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("vincent@dev.nul")).RSVP(), false);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("jules@dev.nul")).status(), Attendee::Accepted);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("jules@dev.nul")).RSVP(), false);
         } else {
             QCOMPARE(incidence->attendeeByMail(s_ourEmail).status(), Attendee::Accepted);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul")).status(), Attendee::Declined);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul")).status(), Attendee::Delegated);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul")).status(), Attendee::Accepted);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("mia@dev.nul")).status(), Attendee::Declined);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("vincent@dev.nul")).status(), Attendee::Delegated);
+            QCOMPARE(incidence->attendeeByMail(QStringLiteral("jules@dev.nul")).status(), Attendee::Accepted);
         }
         delete fetchJob;
     }
@@ -690,7 +690,7 @@ private Q_SLOTS:
 
         QTest::newRow("try delete,create") << items << changeTypes << failureExpectedList << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // Creation succeeds but deletion doesn't ( valid, inexistant item case )
+        // Creation succeeds but deletion doesn't ( valid, inexistent item case )
         items.clear();
         items << item() << Item(10101010);
         changeTypes.clear();
@@ -704,7 +704,7 @@ private Q_SLOTS:
 
         QTest::newRow("create,try delete v2") << items << changeTypes << failureExpectedList << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // deletion doesn't succeed, but creation does ( valid, inexistant item case )
+        // deletion doesn't succeed, but creation does ( valid, inexistent item case )
         items.clear();
         items << Item(10101010) << item();
         changeTypes.clear();
