@@ -9,8 +9,13 @@
 #pragma once
 
 #include <QSortFilterProxyModel>
-
-template<class T> class QVector;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+template<typename T>
+class QVector;
+#else
+template<typename T>
+class QList;
+#endif
 
 namespace Akonadi
 {
